`ePlot2` <-
function(marker1ID, marker2ID, mChr, mPos, chroms, bandwidth=10, nrpoints=Inf)
{
  library(geneplotter)

  valid.chroms = c(1:90, "X", "Y")
  wrongChr = chroms[!(chroms %in% valid.chroms)]
  if(length(wrongChr)>0){
    stop(wrongChr, " are not valid chromosome labels\n")
  }

  todrop = which(!(mChr %in% chroms))
  mChr[todrop] = NA
  mPos[todrop] = NA
  mChr[mChr=="X"] = 99
  mChr[mChr=="Y"] = 100
  mChr = as.integer(mChr)
  mPos = as.numeric(mPos)

  chrs = unique(mChr)
  chrs = sort(as.numeric(chrs))
  num.chrs = chrs[chrs <= 90]
  chr.chrs = c(num.chrs, "X", "Y")
  max.num = max(num.chrs)
  if(max.num > length(num.chrs)){
    str = "there is no marker/gene locaiton information for some chromosomes\n"
    stop(str)
  }
  mChr[mChr==99]  = max.num+1
  mChr[mChr==100] = max.num+2

  chrMax = tapply(mPos, mChr, max, na.rm=TRUE, simplify = FALSE)

  nChr = length(chrMax)
  chrLen = c(0, cumsum(chrMax))
  mp = mPos + chrLen[mChr]

  ymax = chrLen[nChr+1]
  bdr1 = -0.020*ymax
  bdr2 = -0.010*ymax

  layout(matrix(1:4,ncol=2), heights = c(7,2), widths=c(7,2))

  par(mar=c(2,0,0,2), bty="n")
  
  mpos1 = mp[marker1ID]
  mpos2 = mp[marker2ID]

  smoothScatter(mpos1, mpos2, pch=21, bandwidth=bandwidth, cex=0.5, 
    nrpoints=nrpoints, xlim=c(0,ymax - bdr1), ylim=c(bdr1,ymax),
    xlab="", ylab="", main="", xaxt="n", yaxt="n")

  nchr.plot = floor(nChr/2)
  rect(rep(-bdr1+ymax,nchr.plot), chrLen[seq(1,nChr,by=2)],
       rep(-bdr2+ymax,nchr.plot), chrLen[seq(2,nChr+1,by=2)],
       border=NA, col="orange")
  rect(chrLen[seq(1,nChr,by=2)], rep(bdr1,nchr.plot),
       chrLen[seq(2,nChr+1,by=2)], rep(bdr2,nchr.plot),
       border=NA, col="orange")

  kp = seq(1,nChr,by=2)
  ats = 0.5*(chrLen[-1] + chrLen[-length(chrLen)])

#  mtext(chr.chrs[kp], at=ats[kp], side=1, line=-0.5, cex=0.8)
#  mtext(chr.chrs[kp], at=ats[kp], side=4, line=-0.5, cex=0.8)

  # ---------------------------------------------------------  
  # frequency of marker ID 1
  # ---------------------------------------------------------  

  et = table(marker1ID)
  mIDs = as.numeric(names(et))

  par(mar=c(2,0,0,2))
  plot(mp[mIDs], -et, xlim=c(0,ymax - bdr1),
    type="h", xlab="", ylab="", xaxt="n", yaxt="n", bty="n")
  abline(v=chrLen, lty=2, col="seagreen")
  mtext(chr.chrs[kp], at=ats[kp], side=3, line=0, cex=0.8)
  abline(h=0, col="grey")
  gap = 5*round(max(et)/10)
  axis(side=4, at=seq(0, -max(et), -gap), labels=seq(0, max(et), gap))

  # ---------------------------------------------------------  
  # frequency of marker ID 2
  # ---------------------------------------------------------  

  et   = table(marker2ID)
  mIDs = as.numeric(names(et))
  et   = as.numeric(et)

  par(mar=c(2,0,0,2))
  plot(et, mp[mIDs], ylim=c(bdr1,ymax), type="n", xlab="", ylab="", 
    xaxt="n", yaxt="n", bty="n")
  gap = 5*round(max(et)/10)
  axis(side=1, at=seq(0, max(et), gap))
  
  segments(0, mp[mIDs], et, mp[mIDs])
  abline(h=chrLen, lty=2, col="seagreen")
  abline(v=0, col="grey")
  mtext(chr.chrs[kp], at=ats[kp], side=2, line=0, cex=0.8)
}

